import React from 'react';
import purebem from 'purebem';
import useAutoFocus from '@billogram/use-auto-focus';
import useClickOutside from '@billogram/use-click-outside';
import useDropdown from '@billogram/use-dropdown';
import usePrevious from '@billogram/use-previous';
import './FoundationDropdown.scss';
export default /*#__PURE__*/React.forwardRef(function FoundationDropdown(_ref, ref) {
  var _ref$autoFocus = _ref.autoFocus,
      autoFocus = _ref$autoFocus === void 0 ? false : _ref$autoFocus,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$emptyText = _ref.emptyText,
      emptyText = _ref$emptyText === void 0 ? '' : _ref$emptyText,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$toggled = _ref.toggled,
      toggled = _ref$toggled === void 0 ? false : _ref$toggled,
      _ref$ui = _ref.ui,
      ui = _ref$ui === void 0 ? 'gray' : _ref$ui,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;
  var block = purebem('foundation-dropdown');
  var listRef = React.useRef(null);
  var optionsRef = React.useRef(new Map());

  var _useDropdown = useDropdown({
    disabled: disabled,
    listNode: listRef.current,
    optionNodes: Array.from(optionsRef.current.values()),
    options: options,
    onChange: onChange,
    value: value
  }),
      change = _useDropdown.change,
      close = _useDropdown.close,
      expanded = _useDropdown.expanded,
      handleKeyDown = _useDropdown.handleKeyDown,
      handleKeyPress = _useDropdown.handleKeyPress,
      selectedOption = _useDropdown.selectedOption,
      highlightedIndex = _useDropdown.highlightedIndex,
      toggle = _useDropdown.toggle;

  var dropdownRef = React.useRef(null);
  useClickOutside(dropdownRef, close);
  var buttonRef = React.useRef(null);
  useAutoFocus(buttonRef, autoFocus);
  React.useImperativeHandle(ref, function () {
    return {
      focus: function focus() {
        if (buttonRef.current !== null) {
          buttonRef.current.focus();
        }
      }
    };
  });
  var prevExpanded = usePrevious(expanded, false);
  React.useLayoutEffect(function () {
    if (prevExpanded && !expanded && buttonRef.current !== null) {
      buttonRef.current.focus();
    }
  });
  var text = selectedOption !== null ? selectedOption.textSelected !== '' && selectedOption.textSelected !== void 0 ? selectedOption.textSelected : selectedOption.text : emptyText; // We intend to follow these resources as closely as possible (not quite there yet though):
  //  - https://www.w3.org/TR/wai-aria-practices/#Listbox
  //  - https://www.w3.org/TR/wai-aria-practices/examples/listbox/listbox-collapsible.html

  return /*#__PURE__*/React.createElement("div", {
    className: block(),
    onKeyDown: handleKeyDown,
    onKeyPress: handleKeyPress,
    ref: dropdownRef
  }, /*#__PURE__*/React.createElement("div", {
    "aria-expanded": expanded ? true : void 0,
    "aria-haspopup": "listbox",
    className: block('button', {
      disabled: disabled,
      expanded: expanded,
      toggled: toggled,
      ui: ui
    }),
    onClick: toggle,
    ref: buttonRef,
    role: "button",
    tabIndex: !disabled ? 0 : void 0
  }, /*#__PURE__*/React.createElement("div", {
    className: block('button-content')
  }, /*#__PURE__*/React.createElement("span", {
    className: block('button-text')
  }, text), /*#__PURE__*/React.createElement("span", {
    className: block('button-chevron', {
      disabled: disabled,
      expanded: expanded
    })
  }))), /*#__PURE__*/React.createElement("ul", {
    className: block('list', {
      expanded: expanded,
      ui: ui
    }),
    ref: listRef,
    role: "listbox"
  }, options.map(function (option, index) {
    var disabled = option.disabled === true;
    var highlighted = highlightedIndex === index;

    function handleChange() {
      change(option);
    }

    return /*#__PURE__*/React.createElement("li", {
      "aria-selected": highlighted ? true : void 0,
      className: block('list-item', {
        disabled: disabled,
        highlighted: highlighted,
        ui: ui
      }),
      key: option.value,
      onClick: handleChange,
      ref: function ref(c) {
        return optionsRef.current.set(index, c);
      },
      role: "option"
    }, option.text);
  })));
});
//# sourceMappingURL=FoundationDropdown.js.map